@@ -73,7 +73,11 @@ class SqleeRepository:
 
     def create_table(self, name=None, namespace=None):
         if not namespace:
-            raise ValueError("参数不全.")
+            raise ValueError("未提供足够的参数.")
+        for value in ["data", "length", "update", "delete",
+                      "namespace", "count", "sync", "repo"]:
+            if value in namespace:
+                raise ValueError("命名域不可以被命名为: %s." % value)
         make = self.repo.make_folder(path=name)
         self.repo.upload_file(path=URL(name)/".namespace", content=json.dumps(namespace))
         return make
